@@ -12,8 +12,10 @@ sub AutoObject_around_object {
 
     my ( $c, $id ) = @_;
 
+    my $id_can_de_negative = $self->config->{id_can_de_negative} ? '-?' : '';
+
     $self->status_bad_request( $c, message => 'invalid.int' ), $c->detach
-      unless $id =~ /^[0-9]+$/;
+      unless $id =~ /^$id_can_de_negative[0-9]+$/;
 
     $c->stash->{object} = $c->stash->{collection}->search( { "me.id" => $id } );
     $c->stash->{ $config->{object_key} } = $c->stash->{object}->next;
@@ -21,6 +23,6 @@ sub AutoObject_around_object {
     $c->detach('/error_404') unless defined $c->stash->{ $config->{object_key} };
 
     $self->$orig(@_);
-};
+}
 
 1;
